MPEG.TS.PMT (MPEG.TS v3.3.14)
View SourceProgram Map Table.
Summary
Functions
Categorizes a stream type as :video, :audio, or :other.
Categorizes a stream based on its stream_id (as an integer value) as :video, :audio, or :other.
Determines if a given stream type is an audio stream.
Determines if a given stream type is a video stream.
Returns true for streams that carry PES packets, using descriptors when needed.
Returns true for stream types that carry PES packets.
Types
@type stream_id_t() :: 0..8191
@type stream_t() :: %{ stream_type: atom(), stream_type_id: stream_type_id_t(), descriptors: list() }
@type stream_type_id_t() :: 0..255
@type streams_t() :: %{required(stream_id_t()) => stream_t()}
Functions
@spec encode_stream_type(atom()) :: stream_id_t()
Categorizes a stream type as :video, :audio, or :other.
Examples
iex> get_stream_category(:H264_AVC)
:video
iex> get_stream_category(:AAC_ADTS)
:audio
iex> get_stream_category(:DVB_SUBTITLE)
:subtitles
Categorizes a stream based on its stream_id (as an integer value) as :video, :audio, or :other.
Examples
iex> get_stream_category_by_id(0x1B)
:video
iex> get_stream_category_by_id(0x0F)
:audio
iex> get_stream_category_by_id(0x42)
:other
Determines if a given stream type is an audio stream.
Examples
iex> is_audio_stream?(:AAC_ADTS)
true
iex> is_audio_stream?(:H264_AVC)
false
Determines if a given stream type is a video stream.
Examples
iex> is_video_stream?(:H264_AVC)
true
iex> is_video_stream?(:AAC_ADTS)
false
Returns true for streams that carry PES packets, using descriptors when needed.
@spec pes_stream_type?(atom() | {atom(), stream_type_id_t()}) :: boolean()
Returns true for stream types that carry PES packets.